==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/ReferringClassInAssocSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ClassAsLinkSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSimpleFormalizerSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSubtypeSet;
import io.ciera.tool.sql.ooaofooa.association.ClassInAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ReferringClassInAssoc;
import io.ciera.tool.sql.ooaofooa.association.ReferringClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsLinkSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSimpleFormalizerSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSubtypeSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassInAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.AttributeReferenceInClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.AttributeReferenceInClassSetImpl;

import java.util.Arrays;
import java.util.List;


public class ReferringClassInAssocSetImpl extends InstanceSet<ReferringClassInAssocSet,ReferringClassInAssoc> implements ReferringClassInAssocSet {

    // attributes
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( ReferringClassInAssoc referringclassinassoc : this ) referringclassinassoc.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ReferringClassInAssoc referringclassinassoc : this ) referringclassinassoc.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( ReferringClassInAssoc referringclassinassoc : this ) referringclassinassoc.setOIR_ID( ref_OIR_ID );
    }


    // selections
    @Override
    public AttributeReferenceInClassSet R111_refers_across_association_via_AttributeReferenceInClass() throws XtumlException {
        AttributeReferenceInClassSet attributereferenceinclassset = new AttributeReferenceInClassSetImpl();
        for ( ReferringClassInAssoc referringclassinassoc : this ) attributereferenceinclassset.addAll( referringclassinassoc.R111_refers_across_association_via_AttributeReferenceInClass() );
        return attributereferenceinclassset;
    }
    @Override
    public ClassInAssociationSet R203_is_a_ClassInAssociation() throws XtumlException {
        ClassInAssociationSet classinassociationset = new ClassInAssociationSetImpl();
        for ( ReferringClassInAssoc referringclassinassoc : this ) classinassociationset.add( referringclassinassoc.R203_is_a_ClassInAssociation() );
        return classinassociationset;
    }
    @Override
    public ClassAsLinkSet R205_is_a_ClassAsLink() throws XtumlException {
        ClassAsLinkSet classaslinkset = new ClassAsLinkSetImpl();
        for ( ReferringClassInAssoc referringclassinassoc : this ) classaslinkset.add( referringclassinassoc.R205_is_a_ClassAsLink() );
        return classaslinkset;
    }
    @Override
    public ClassAsSimpleFormalizerSet R205_is_a_ClassAsSimpleFormalizer() throws XtumlException {
        ClassAsSimpleFormalizerSet classassimpleformalizerset = new ClassAsSimpleFormalizerSetImpl();
        for ( ReferringClassInAssoc referringclassinassoc : this ) classassimpleformalizerset.add( referringclassinassoc.R205_is_a_ClassAsSimpleFormalizer() );
        return classassimpleformalizerset;
    }
    @Override
    public ClassAsSubtypeSet R205_is_a_ClassAsSubtype() throws XtumlException {
        ClassAsSubtypeSet classassubtypeset = new ClassAsSubtypeSetImpl();
        for ( ReferringClassInAssoc referringclassinassoc : this ) classassubtypeset.add( referringclassinassoc.R205_is_a_ClassAsSubtype() );
        return classassubtypeset;
    }


    @Override
    public ReferringClassInAssoc nullElement() {
        return ReferringClassInAssocImpl.EMPTY_REFERRINGCLASSINASSOC;
    }

    @Override
    public ReferringClassInAssocSet emptySet() {
      return new ReferringClassInAssocSetImpl();
    }

    @Override
    public ReferringClassInAssocSet value() {
        return this;
    }

    @Override
    public List<ReferringClassInAssoc> elements() {
        return Arrays.asList(toArray(new ReferringClassInAssoc[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/ReferringClassInAssocSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ClassAsLinkSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSimpleFormalizerSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSubtypeSet;
import io.ciera.tool.sql.ooaofooa.association.ClassInAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ReferringClassInAssoc;
import io.ciera.tool.sql.ooaofooa.association.ReferringClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsLinkSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSimpleFormalizerSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSubtypeSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassInAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.AttributeReferenceInClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.AttributeReferenceInClassSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ReferringClassInAssocSetImpl extends InstanceSet<ReferringClassInAssocSet,ReferringClassInAssoc> implements ReferringClassInAssocSet {

    public ReferringClassInAssocSetImpl() {
    }

    public ReferringClassInAssocSetImpl(Comparator<? super ReferringClassInAssoc> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( ReferringClassInAssoc referringclassinassoc : this ) referringclassinassoc.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( ReferringClassInAssoc referringclassinassoc : this ) referringclassinassoc.setOIR_ID( ref_OIR_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ReferringClassInAssoc referringclassinassoc : this ) referringclassinassoc.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public AttributeReferenceInClassSet R111_refers_across_association_via_AttributeReferenceInClass() throws XtumlException {
        AttributeReferenceInClassSet attributereferenceinclassset = new AttributeReferenceInClassSetImpl();
        for ( ReferringClassInAssoc referringclassinassoc : this ) attributereferenceinclassset.addAll( referringclassinassoc.R111_refers_across_association_via_AttributeReferenceInClass() );
        return attributereferenceinclassset;
    }
    @Override
    public ClassInAssociationSet R203_is_a_ClassInAssociation() throws XtumlException {
        ClassInAssociationSet classinassociationset = new ClassInAssociationSetImpl();
        for ( ReferringClassInAssoc referringclassinassoc : this ) classinassociationset.add( referringclassinassoc.R203_is_a_ClassInAssociation() );
        return classinassociationset;
    }
    @Override
    public ClassAsLinkSet R205_is_a_ClassAsLink() throws XtumlException {
        ClassAsLinkSet classaslinkset = new ClassAsLinkSetImpl();
        for ( ReferringClassInAssoc referringclassinassoc : this ) classaslinkset.add( referringclassinassoc.R205_is_a_ClassAsLink() );
        return classaslinkset;
    }
    @Override
    public ClassAsSimpleFormalizerSet R205_is_a_ClassAsSimpleFormalizer() throws XtumlException {
        ClassAsSimpleFormalizerSet classassimpleformalizerset = new ClassAsSimpleFormalizerSetImpl();
        for ( ReferringClassInAssoc referringclassinassoc : this ) classassimpleformalizerset.add( referringclassinassoc.R205_is_a_ClassAsSimpleFormalizer() );
        return classassimpleformalizerset;
    }
    @Override
    public ClassAsSubtypeSet R205_is_a_ClassAsSubtype() throws XtumlException {
        ClassAsSubtypeSet classassubtypeset = new ClassAsSubtypeSetImpl();
        for ( ReferringClassInAssoc referringclassinassoc : this ) classassubtypeset.add( referringclassinassoc.R205_is_a_ClassAsSubtype() );
        return classassubtypeset;
    }


    @Override
    public ReferringClassInAssoc nullElement() {
        return ReferringClassInAssocImpl.EMPTY_REFERRINGCLASSINASSOC;
    }

    @Override
    public ReferringClassInAssocSet emptySet() {
      return new ReferringClassInAssocSetImpl();
    }

    @Override
    public ReferringClassInAssocSet emptySet(Comparator<? super ReferringClassInAssoc> comp) {
      return new ReferringClassInAssocSetImpl(comp);
    }

    @Override
    public ReferringClassInAssocSet value() {
        return this;
    }

    @Override
    public List<ReferringClassInAssoc> elements() {
        return Arrays.asList(toArray(new ReferringClassInAssoc[0]));
    }

}
